package com.acmebank.domain;

import java.io.Serializable;
import java.util.Set;

import javax.persistence.CollectionTable;
import javax.persistence.Column;
import javax.persistence.ElementCollection;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

@Entity
@Table(name = "USERS")
public class User implements Serializable {
	private static final long serialVersionUID = 1L;

	@Id
	@GeneratedValue
	private long id;

	@NotNull(message = "User must have a username.")
	@Size(min = 7, max = 30, message = "Username must be between 7 and 30 characters.")
	private String username;

	@NotNull(message = "User must have a password.")
	@Size(min = 7, max = 30, message = "Password must be between 7 and 30 characters.")
	private String password;

	@NotNull(message = "User must have a first name.")
	@Size(min = 2, max = 100, message = "First name must be between 2 and 100 characters.")
	@Column(name = "FIRST_NAME")
	private String firstName;

	@NotNull(message = "User must have a last name.")
	@Size(min = 2, max = 100, message = "Last name must be between 2 and 100 characters.")
	@Column(name = "LAST_NAME")
	private String lastName;

	@ElementCollection
	@CollectionTable(name = "NICKNAMES")
	@Column(name = "NICKNAME")
	private Set<String> nicknames;

	public long getId() {
		return id;
	}

	public void setId(long id) {
		this.id = id;
	}

	public String getUsername() {
		return username;
	}

	public void setUsername(String username) {
		this.username = username;
	}

	public String getPassword() {
		return password;
	}

	public void setPassword(String password) {
		this.password = password;
	}

	public String getFirstName() {
		return firstName;
	}

	public void setFirstName(String firstName) {
		this.firstName = firstName;
	}

	public String getLastName() {
		return lastName;
	}

	public void setLastName(String lastName) {
		this.lastName = lastName;
	}

	public Set<String> getNicknames() {
		return nicknames;
	}

	public void setNicknames(Set<String> nicknames) {
		this.nicknames = nicknames;
	}

	@Override
	public String toString() {
		return "[User[id=" + id + "][username=" + username + "][password="
				+ password + "][firstName=" + firstName + "][lastName="
				+ lastName + "][nicknames=" + nicknames + "]]";
	}
}
